]> rtime.felk.cvut.cz Git - hubacji1/psp.git/blobdiff - api/psp.h
Use forward parking macro
[hubacji1/psp.git] / api / psp.h
index 26a8c0e54bfe114b6ad286999c27aa626588ceb0..2294a5b3f4175539062ebee59cd01b86ecc634f4 100644 (file)
--- a/api/psp.h
+++ b/api/psp.h
@@ -7,6 +7,8 @@
 #include "bcar.h"
 #include "pslot.h"
 
+#define FORWARD_PARKING 1
+
 /*! \brief Parking Slot Planner basic class.
 
 \param cc Current bicycle car.
@@ -19,11 +21,17 @@ class PSPlanner {
                 BicycleCar gc_;
                 ParkingSlot ps_;
 
-                // find entry to slot by reverse approach
+                unsigned int c_ = 0; // number of cusps
+                std::vector<BicycleCar> cusps_;
+
+                // find entry to slot
                 void fe_parallel();
                 void fe_perpendicular();
+                // find entry to slot by reverse approach
                 void fer_parallel();
                 void fer_perpendicular();
+                // set goal car
+                void gc_to_4();
         public:
                 /*! \brief Return `true` if there is collision.
 
@@ -48,6 +56,12 @@ class PSPlanner {
                 Set the goal car guessed from the parking slot.
                 */
                 void guess_gc();
+                /*! \brief Return last maneuver to the parking slot.
+
+                Return path from entry point towards parking slot, such
+                that ``cc`` is inside the parking slot at the end.
+                */
+                std::vector<BicycleCar> last_maneuver();
                 /*! \brief Has current car `cc` left?
 
                 Return `true` if the current car `cc` left the parking
@@ -65,12 +79,16 @@ class PSPlanner {
                 When any `BicycleCar` of possible inits is reached, then
                 parking maneuver is a peace of cake.
 
+                \param cnt Number of inits.
                 \param dist Distance between inits.
                 */
-                std::vector<BicycleCar> possible_inits(double dist);
-                std::vector<BicycleCar> possible_inits()
+                std::vector<BicycleCar> possible_goals(
+                        unsigned int cnt,
+                        double dist
+                );
+                std::vector<BicycleCar> possible_goals()
                 {
-                        return this->possible_inits(1);
+                        return this->possible_goals(10, 0.5);
                 }
 
                 // find entry
@@ -88,6 +106,9 @@ class PSPlanner {
                 BicycleCar &gc() { return this->gc_; }
                 ParkingSlot &ps() { return this->ps_; }
 
+                unsigned int c() const { return this->c_; }
+                std::vector<BicycleCar> &cusps() { return this->cusps_; }
+
                 PSPlanner();
 };